@@ -1,4 +1,4 @@
-//@line 41 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/nsContextMenu.js"
+//@line 41 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/nsContextMenu.js"
 
 /*------------------------------ nsContextMenu ---------------------------------
 |   This JavaScript "class" is used to implement the browser's content-area    |
@@ -17,6 +17,7 @@ function nsContextMenu( xulMenu ) {
     this.popupURL       = null;
     this.onTextInput    = false;
     this.onImage        = false;
+    this.onLoadedImage  = false;
     this.onLink         = false;
     this.onMailtoLink   = false;
     this.onSaveableLink = false;
@@ -93,7 +94,7 @@ nsContextMenu.prototype = {
         this.showItem( "context-savelink", this.onSaveableLink );
 
         // Save image depends on whether there is one.
-        this.showItem( "context-saveimage", this.onImage );
+        this.showItem( "context-saveimage", this.onLoadedImage );
         
         this.showItem( "context-sendimage", this.onImage );
     },
@@ -107,11 +108,11 @@ nsContextMenu.prototype = {
         this.showItem( "context-sep-properties", !( this.inDirList || this.isTextSelected || this.onTextInput ) );
         // Set As Wallpaper depends on whether an image was clicked on, and only works on Windows.
         var isWin = navigator.appVersion.indexOf("Windows") != -1;
-        this.showItem( "context-setWallpaper", isWin && this.onImage );
+        this.showItem( "context-setWallpaper", isWin && this.onLoadedImage );
 
         this.showItem( "context-sep-image", this.onImage );
 
-        if( isWin && this.onImage )
+        if( isWin && this.onLoadedImage )
             // Disable the Set As Wallpaper menu item if we're still trying to load the image
           this.setItemAttr( "context-setWallpaper", "disabled", (("complete" in this.target) && !this.target.complete) ? "true" : null );
 
@@ -202,6 +203,7 @@ nsContextMenu.prototype = {
         }
         // Initialize contextual info.
         this.onImage    = false;
+        this.onLoadedImage = false;
         this.onStandaloneImage = false;
         this.onMetaDataItem = false;
         this.onTextInput = false;
@@ -217,15 +219,16 @@ nsContextMenu.prototype = {
 
         // See if the user clicked on an image.
         if ( this.target.nodeType == Node.ELEMENT_NODE ) {
-             if ( this.target instanceof Components.interfaces.nsIImageLoadingContent &&
-                  this.target.currentURI != null ) {
+            if ( this.target instanceof Components.interfaces.nsIImageLoadingContent && this.target.currentURI  ) {
                 this.onImage = true;
+                var request = this.target.getRequest( Components.interfaces.nsIImageLoadingContent.CURRENT_REQUEST );
+                if (request && (request.imageStatus & request.STATUS_SIZE_AVAILABLE))
+                    this.onLoadedImage = true;
                 this.imageURL = this.target.currentURI.spec;
 
-                var documentType = window._content.document.contentType;
-                if ( documentType.substr(0,6) == "image/" )
-                    this.onStandaloneImage = true;
-             } else if ( this.target instanceof HTMLInputElement) {
+                if ( this.target.ownerDocument instanceof ImageDocument )
+                   this.onStandaloneImage = true;
+            } else if ( this.target instanceof HTMLInputElement) {
                type = this.target.getAttribute("type");
                this.onTextInput = this.isTargetATextBox(this.target);
             } else if ( this.target instanceof HTMLTextAreaElement ) {
@@ -472,7 +475,7 @@ nsContextMenu.prototype = {
         // when there is one
         var reference = null;
         if (context == "selection")
-          reference = focusedWindow.__proto__.getSelection.call(focusedWindow);
+          reference = focusedWindow.getSelection();
         else if (context == "mathml")
           reference = this.target;
         else
@@ -557,31 +560,6 @@ nsContextMenu.prototype = {
                                          Components.interfaces.nsIClipboardHelper );
         clipboard.copyString(addresses);
     },    
-    addBookmark : function() {
-      var docshell = document.getElementById( "content" ).webNavigation;
-      BookmarksUtils.addBookmark( docshell.currentURI.spec,
-                                  docshell.document.title,
-                                  docshell.document.characterSet,
-                                  false );
-    },
-    addBookmarkForFrame : function() {
-      var doc = this.target.ownerDocument;
-      var uri = doc.location.href;
-      var title = doc.title;
-      if ( !title )
-        title = uri;
-      BookmarksUtils.addBookmark( uri,
-                                  title,
-                                  doc.characterSet,
-                                  false );
-    },
-    // Open Metadata window for node
-    showMetadata : function () {
-        window.openDialog(  "chrome://navigator/content/metadata.xul",
-                            "_blank",
-                            "scrollbars,resizable,chrome,dialog=no",
-                            this.target);
-    },
 
     ///////////////
     // Utilities //
@@ -703,7 +681,7 @@ nsContextMenu.prototype = {
     
     searchSelected : function() {
         var focusedWindow = document.commandDispatcher.focusedWindow;
-        var searchStr = focusedWindow.__proto__.getSelection.call(focusedWindow);
+        var searchStr = focusedWindow.getSelection();;
         searchStr = searchStr.toString();
         searchStr = searchStr.replace( /^\s+/, "" );
         searchStr = searchStr.replace(/(\n|\r|\t)+/g, " ");
@@ -754,71 +732,3 @@ nsContextMenu.prototype = {
       return false;  
     }
 };
-
-/*************************************************************************
- *
- *   nsDefaultEngine : nsIObserver
- *
- *************************************************************************/
-function nsDefaultEngine()
-{
-    try
-    {
-        var pb = Components.classes["@mozilla.org/preferences-service;1"].
-                   getService(Components.interfaces.nsIPrefBranch);
-        var pbi = pb.QueryInterface(
-                    Components.interfaces.nsIPrefBranch2);
-        pbi.addObserver(this.domain, this, false);
-
-        // reuse code by explicitly invoking initial |observe| call
-        // to initialize the |icon| and |name| member variables
-        this.observe(pb, "", this.domain);
-    }
-    catch (ex)
-    {
-    }
-}
-
-nsDefaultEngine.prototype = 
-{
-    name: "",
-    icon: "",
-    domain: "browser.search.defaultengine",
-
-    // nsIObserver implementation
-    observe: function(aPrefBranch, aTopic, aPrefName)
-    {
-        try
-        {
-            var rdf = Components.
-                        classes["@mozilla.org/rdf/rdf-service;1"].
-                        getService(Components.interfaces.nsIRDFService);
-            var ds = rdf.GetDataSource("rdf:internetsearch");
-            var defaultEngine = aPrefBranch.getCharPref(aPrefName);
-            var res = rdf.GetResource(defaultEngine);
-
-            // get engine ``pretty'' name
-            const kNC_Name = rdf.GetResource(
-                               "http://home.netscape.com/NC-rdf#Name");
-            var engineName = ds.GetTarget(res, kNC_Name, true);
-            if (engineName)
-            {
-                this.name = engineName.QueryInterface(
-                              Components.interfaces.nsIRDFLiteral).Value;
-            }
-
-            // get URL to engine vendor icon
-            const kNC_Icon = rdf.GetResource(
-                               "http://home.netscape.com/NC-rdf#Icon");
-            var iconURL = ds.GetTarget(res, kNC_Icon, true);
-            if (iconURL)
-            {
-                this.icon = iconURL.QueryInterface(
-                  Components.interfaces.nsIRDFLiteral).Value;
-            }
-        }
-        catch (ex)
-        {
-        }
-    }
-}
