@@ -1,4 +1,4 @@
-//@line 37 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/extensions/newsblog/content/Feed.js"
+//@line 37 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/extensions/newsblog/content/Feed.js"
 
 
 // error codes used to inform the consumer about attempts to download a feed
@@ -31,9 +31,9 @@ var FeedCache =
 
   normalizeHost: function (aUrl)
   {
-    normalizedUrl = Components.classes["@mozilla.org/network/standard-url;1"].
-                    createInstance(Components.interfaces.nsIURI);
-    normalizedUrl.spec = aUrl;    
+    var ioService = Components.classes["@mozilla.org/network/io-service;1"].
+                    getService(Components.interfaces.nsIIOService);
+    var normalizedUrl = ioService.newURI(aUrl, null, null);
     normalizedUrl.host = normalizedUrl.host.toLowerCase();
     return normalizedUrl.spec;
   }
@@ -171,7 +171,13 @@ Feed.prototype =
     if (feed.downloadCallback) 
     {
       // if the http status code is a 304, then the feed has not been modified since we last downloaded it.
-      feed.downloadCallback.downloaded(feed, request.status == 304 ? kNewsBlogNoNewItems : kNewsBlogRequestFailure);
+      var error = kNewsBlogRequestFailure;
+      try
+      {
+        if (request.status == 304)
+          error = kNewsBlogNoNewItems;
+      } catch (ex) {}
+      feed.downloadCallback.downloaded(feed, error);
     }
     
     FeedCache.removeFeed(url);
@@ -207,8 +213,11 @@ Feed.prototype =
     return title;
   },
 
-  set title (aNewTitle) 
+  set title (aNewTitle)
   {
+    if (!aNewTitle)
+      return;
+
     var ds = getSubscriptionsDS(this.server);
     aNewTitle = rdf.GetLiteral(aNewTitle);
     var old_title = ds.GetTarget(this.resource, DC_TITLE, true);
@@ -277,6 +286,9 @@ Feed.prototype =
 
   set link (aNewLink)
   {
+    if (!aNewLink)
+      return;
+
     var ds = getSubscriptionsDS(this.server);
     aNewLink = rdf.GetLiteral(aNewLink);
     var old_link = ds.GetTarget(this.resource, RSS_LINK, true);
