@@ -1,4 +1,4 @@
-//@line 41 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/commandglue.js"
+//@line 41 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/commandglue.js"
 /*
  * Command-specific code. This stuff should be called by the widgets
  */
@@ -25,12 +25,7 @@ var MSG_FOLDER_FLAG_QUEUE = 0x0800;
 var MSG_FOLDER_FLAG_INBOX = 0x1000;
 var MSG_FOLDER_FLAG_TEMPLATES = 0x400000;
 var MSG_FOLDER_FLAG_JUNK = 0x40000000;
-
-function OpenURL(url)
-{
-  messenger.SetWindow(window, msgWindow);
-  messenger.OpenURL(url);
-}
+var MSG_FOLDER_FLAG_FAVORITE = 0x80000000;
 
 function GetMsgFolderFromResource(folderResource)
 {
@@ -57,30 +52,6 @@ function GetServer(uri)
     return null;
 }
 
-function LoadMessageByUri(uri)
-{
-  //dump("XXX LoadMessageByUri " + uri + " vs " + gCurrentDisplayedMessage + "\n");
-  if(uri != gCurrentDisplayedMessage)
-  {
-        dump("fix this, get the nsIMsgDBHdr and the nsIMsgFolder from the uri...\n");
-/*
-    var resource = RDF.GetResource(uri);
-    var message = resource.QueryInterface(Components.interfaces.nsIMessage);
-    if (message)
-      setTitleFromFolder(message.msgFolder, message.mimef2DecodedSubject);
-
-    var nsIMsgFolder = Components.interfaces.nsIMsgFolder;
-    if (message.msgFolder.server.downloadOnBiff)
-      message.msgFolder.biffState = nsIMsgFolder.nsMsgBiffState_NoMail;
-*/
-
-    gCurrentDisplayedMessage = uri;
-    gHaveLoadedMessage = true;
-    OpenURL(uri);
-  }
-
-}
-
 function setTitleFromFolder(msgfolder, subject)
 {
     var wintype = document.firstChild.getAttribute('windowtype');
@@ -122,9 +93,9 @@ function setTitleFromFolder(msgfolder, subject)
     }
     }
 
-//@line 165 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/commandglue.js"
+//@line 136 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/commandglue.js"
     title += " - " + gBrandBundle.getString("brandShortName");
-//@line 167 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/commandglue.js"
+//@line 138 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/commandglue.js"
     document.title = title;
 }
 
@@ -163,7 +134,8 @@ function ChangeFolderByURI(uri, viewType, viewFlags, sortType, sortOrder)
     msgWindow.openFolder = null;
 
     ClearThreadPane();
-    
+    UpdateStatusQuota(null);
+
     // Load AccountCentral page here.
     ShowAccountCentral();
 
@@ -326,9 +298,8 @@ function RerootFolder(uri, newFolder, viewType, viewFlags, sortType, sortOrder)
   }
   // that should have initialized gDBView, now re-root the thread pane
   RerootThreadPane();
-
   SetUpToolbarButtons(uri);
-
+  UpdateFolderLocationPicker(gMsgFolderSelected);
   UpdateStatusMessageCounts(gMsgFolderSelected);
   
   // hook for extra toolbar items
@@ -338,10 +309,10 @@ function RerootFolder(uri, newFolder, viewType, viewFlags, sortType, sortOrder)
   if (gSearchSession && !gVirtualFolderTerms) // another var might be better...
   {
     viewDebug("doing a xf folder search in rerootFolder\n");
-    gDBView.searchSession = gSearchSession;
-    gSearchSession.search(msgWindow);
+    ViewChangeByFolder(newFolder);
+    gPreQuickSearchView = null; // don't remember the cross folder search
+    ScrollToMessageAfterFolderLoad(newFolder);
   }
-
 }
 
 function SwitchView(command)
@@ -349,7 +320,7 @@ function SwitchView(command)
   // when switching thread views, we might be coming out of quick search
   // or a message view.
   // first set view picker to all
-  ViewMessagesBy("viewPickerAll");
+  ViewChangeByValue(kViewItemAll);
 
   // clear the QS text, if we need to
   ClearQSIfNecessary();
@@ -467,11 +438,72 @@ function UpdateStatusMessageCounts(folder)
 
     unreadElement.setAttribute("label", numUnread);
     totalElement.setAttribute("label", numTotal);
+    unreadElement.hidden = false;
+    totalElement.hidden = false;
 
   }
 
 }
 
+var gQuotaUICache;
+function UpdateStatusQuota(folder)
+{
+  if (!(folder && // no folder selected
+        folder instanceof Components.interfaces.nsIMsgImapMailFolder)) // POP etc.
+  {
+    if (typeof(gQuotaUICache) == "object") // ever shown quota
+      gQuotaUICache.panel.hidden = true;
+    return;
+  }
+  folder = folder.QueryInterface(Components.interfaces.nsIMsgImapMailFolder);
+
+  // get element references and prefs
+  if (typeof(gQuotaUICache) != "object")
+  {
+    gQuotaUICache = new Object();
+    gQuotaUICache.meter = document.getElementById("quotaMeter");
+    gQuotaUICache.panel = document.getElementById("quotaPanel");
+    gQuotaUICache.label = document.getElementById("quotaLabel");
+    const kBranch = "mail.quota.mainwindow_threshold.";
+    gQuotaUICache.showTreshold = gPrefBranch.getIntPref(kBranch + "show");
+    gQuotaUICache.warningTreshold = gPrefBranch.getIntPref(kBranch + "warning");
+    gQuotaUICache.criticalTreshold = gPrefBranch.getIntPref(kBranch + "critical");
+  }
+
+  var valid = {value: null};
+  var used = {value: null};
+  var max = {value: null};
+  try {
+    // get data from backend
+    folder.getQuota(valid, used, max);
+  } catch (e) { dump(e + "\n"); }
+  if (valid.value && max.value > 0)
+  {
+    var percent = Math.round(used.value / max.value * 100);
+
+    // show in UI
+    if (percent < gQuotaUICache.showTreshold)
+      gQuotaUICache.panel.hidden = true;
+    else
+    {
+      gQuotaUICache.panel.hidden = false;
+      gQuotaUICache.meter.setAttribute("value", percent);
+           // do not use value property, because that is imprecise (3%)
+           // for optimization that we don't need here
+      var label = percent + "%";
+      gQuotaUICache.label.value = label;
+      if (percent < gQuotaUICache.warningTreshold)
+        gQuotaUICache.panel.removeAttribute("alert");
+      else if (percent < gQuotaUICache.criticalTreshold)
+        gQuotaUICache.panel.setAttribute("alert", "warning");
+      else
+        gQuotaUICache.panel.setAttribute("alert", "critical");
+    }
+  }
+  else
+    gQuotaUICache.panel.hidden = true;
+}
+
 function ConvertColumnIDToSortType(columnID)
 {
   var sortKey;
@@ -513,8 +545,8 @@ function ConvertColumnIDToSortType(columnID)
     case "threadCol":
       sortKey = nsMsgViewSortType.byThread;
       break;
-    case "labelCol":
-      sortKey = nsMsgViewSortType.byLabel;
+    case "tagsCol":
+      sortKey = nsMsgViewSortType.byTags;
       break;
     case "junkStatusCol":
       sortKey = nsMsgViewSortType.byJunkStatus;
@@ -526,8 +558,23 @@ function ConvertColumnIDToSortType(columnID)
 	    sortKey = nsMsgViewSortType.byAttachments;
 	    break;
     default:
-      dump("unsupported sort column: " + columnID + "\n");
-      sortKey = 0;
+      
+      //no predefined column handler - lets check if there is a custom column handler
+      try {
+        //try to grab the columnHandler (an error is thrown if it does not exist)
+        columnHandler = gDBView.getColumnHandler(columnID);
+
+        //it exists - save this column ID in the customSortCol property of dbFolderInfo
+        //for later use (see nsIMsgDBView.cpp)
+        gDBView.db.dBFolderInfo.setProperty('customSortCol', columnID);
+        
+        sortKey = nsMsgViewSortType.byCustom;
+      }
+      catch(err)
+      {
+        dump("unsupported sort column: " + columnID + " - no custom handler installed. (Error was: " + err + ")\n");
+        sortKey = 0;
+      }
       break;
   }
   return sortKey;
@@ -566,8 +613,8 @@ function ConvertSortTypeToColumnID(sortKey)
     case nsMsgViewSortType.byStatus:
       columnID = "statusCol";
       break;
-    case nsMsgViewSortType.byLabel:
-      columnID = "labelCol";
+    case nsMsgViewSortType.byTags:
+      columnID = "tagsCol";
       break;
     case nsMsgViewSortType.bySize:
       columnID = "sizeCol";
@@ -582,8 +629,7 @@ function ConvertSortTypeToColumnID(sortKey)
       columnID = "threadCol";
       break;
     case nsMsgViewSortType.byId:
-      // there is no orderReceivedCol, so return null
-      columnID = null;
+      columnID = "idCol";
       break;
     case nsMsgViewSortType.byJunkStatus:
       columnID = "junkStatusCol";
@@ -591,9 +637,23 @@ function ConvertSortTypeToColumnID(sortKey)
 	  case nsMsgViewSortType.byAttachments:
 	    columnID = "attachmentCol";
 	    break;
+    case nsMsgViewSortType.byCustom:
+
+      //TODO: either change try() catch to if (property exists) or restore the getColumnHandler() check
+      try //getColumnHandler throws an errror when the ID is not handled
+      {
+        columnID = gDBView.db.dBFolderInfo.getProperty('customSortCol');
+      }
+
+      catch (err) { //error - means no handler
+        dump("ConvertSortTypeToColumnID: custom sort key but no handler for column '" + columnID + "'\n");
+        columnID = "dateCol";
+      }
+
+      break;
     default:
       dump("unsupported sort key: " + sortKey + "\n");
-      columnID = null;
+      columnID = "dateCol";
       break;
   }
   return columnID;
@@ -687,6 +747,8 @@ function CreateDBView(msgFolder, viewType, viewFlags, sortType, sortOrder)
   gDBView.suppressMsgDisplay = IsMessagePaneCollapsed();
 
   UpdateSortIndicators(gCurSortType, sortOrder);
+  var ObserverService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService);
+  ObserverService.notifyObservers(msgFolder, "MsgCreateDBView", viewType + ":" + viewFlags);
 }
 
 //------------------------------------------------------------
@@ -779,8 +841,9 @@ function FolderPaneSelectionChange()
         if (msgFolder == gMsgFolderSelected)
            return;
 
-	gPrevSelectedFolder = gMsgFolderSelected;
+	      gPrevSelectedFolder = gMsgFolderSelected;
         gMsgFolderSelected = msgFolder;
+        UpdateFolderLocationPicker(gMsgFolderSelected);
         var folderFlags = msgFolder.flags;
         // if this is same folder, and we're not showing a virtual folder
         // then do nothing.
@@ -813,6 +876,7 @@ function FolderPaneSelectionChange()
                   var dbFolderInfo = msgDatabase.dBFolderInfo;
                   sortType = dbFolderInfo.sortType;
                   sortOrder = dbFolderInfo.sortOrder;
+                  viewFlags = dbFolderInfo.viewFlags;
                   if (folderFlags & MSG_FOLDER_FLAG_VIRTUAL)
                   {
                     viewType = nsMsgViewType.eShowQuickSearchResults;
@@ -869,8 +933,7 @@ function FolderPaneSelectionChange()
                 gPreQuickSearchView.close();
                 gPreQuickSearchView = null;  
               }
-              
-              clearQuickSearchAfterFolderChange();
+              ClearQSIfNecessary();
             }
             ClearMessagePane();
 
@@ -965,25 +1028,6 @@ function Redo()
 {
     messenger.Redo(msgWindow);
 }
-var mailOfflineObserver = {
-  observe: function(subject, topic, state) {
-    // sanity checks
-    if (topic != "network:offline-status-changed") return;
-    MailOfflineStateChanged(state == "offline");
-  }
-}
-
-function AddMailOfflineObserver() 
-{
-  var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService); 
-  observerService.addObserver(mailOfflineObserver, "network:offline-status-changed", false);
-}
-
-function RemoveMailOfflineObserver()
-{
-  var observerService = Components.classes["@mozilla.org/observer-service;1"].getService(Components.interfaces.nsIObserverService); 
-  observerService.removeObserver(mailOfflineObserver,"network:offline-status-changed");
-}
 
 function getSearchTermString(searchTerms)
 {
@@ -997,6 +1041,11 @@ function getSearchTermString(searchTerms)
     if (condition.length > 1)
       condition += ' ';
     
+    if (term.matchAll)
+    {
+        condition = "ALL";
+        break;
+    }
     condition += (term.booleanAnd) ? "AND (" : "OR (";
     condition += term.termAsString + ')';
   }
@@ -1106,6 +1155,7 @@ function CreateGroupedSearchTerms(searchTermsArray)
     var searchTermForQS = searchSession.createTerm();
     searchTermForQS.value = searchTerm.value;
     searchTermForQS.attrib = searchTerm.attrib;
+    searchTermForQS.arbitraryHeader = searchTerm.arbitraryHeader
     searchTermForQS.op = searchTerm.op;
 
     // mark the first node as a group
