@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailCore.js"
+//@line 38 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailCore.js"
 
 /*
  * Core mail routines used by all of the major mail windows (address book, 3-pane, compose and stand alone message window).
@@ -15,8 +15,12 @@ function CustomizeMailToolbar(id)
     
   var customizePopup = document.getElementById("CustomizeMailToolbar"); 
   customizePopup.setAttribute("disabled", "true");
-   
-  window.openDialog("chrome://global/content/customizeToolbar.xul", "CustomizeToolbar",
+
+  var wintype = document.documentElement.getAttribute("windowtype");
+  wintype = wintype.replace(/:/g, "");
+
+  window.openDialog("chrome://global/content/customizeToolbar.xul",
+                    "CustomizeToolbar"+wintype,
                     "chrome,all,dependent", document.getElementById(id));
 }
 
@@ -33,6 +37,21 @@ function MailToolboxCustomizeDone(aToolboxChanged)
   if (document.getElementById("button-file"))
     SetupMoveCopyMenus('button-file', accountManagerDataSource, folderDataSource);
 
+  // make sure the mail views search box is initialized
+  if (document.getElementById("mailviews-container"))
+    ViewPickerOnLoad();
+    
+  // make sure the folder location picker is initialized
+  if (document.getElementById("folder-location-container"))
+  {
+    loadFolderViewForTree(gCurrentFolderView, document.getElementById('folderLocationPopup').tree);
+    UpdateFolderLocationPicker(gMsgFolderSelected);
+  }
+ 
+  gSearchInput = null;
+  if (document.getElementById("search-container"))
+    GetSearchInput();
+
   var customizePopup = document.getElementById("CustomizeMailToolbar");
   customizePopup.removeAttribute("disabled");
 
@@ -96,12 +115,6 @@ function toImport()
   window.openDialog("chrome://messenger/content/importDialog.xul","importDialog","chrome, modal, titlebar", {importType: "addressbook"});
 }
 
-// this method is overridden by mail-offline.js if we build with the offline extensions
-function CheckOnline()
-{
-  return true; 
-}
-
 // aPaneID
 function openOptionsDialog(aPaneID, aTabID)
 {
@@ -130,29 +143,20 @@ function openOptionsDialog(aPaneID, aTabID)
     openDialog("chrome://messenger/content/preferences/preferences.xul","Preferences", features, aPaneID, aTabID);
 }
 
-function openExtensions(aOpenMode)
+function openAddonsMgr()
 {
   const EMTYPE = "Extension:Manager";
-  
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
-  var needToOpen = true;
-  var windowType = EMTYPE + "-" + aOpenMode;
-  var windows = wm.getEnumerator(windowType);
-  while (windows.hasMoreElements()) {
-    var theEM = windows.getNext().QueryInterface(Components.interfaces.nsIDOMWindowInternal);
-    if (theEM.document.documentElement.getAttribute("windowtype") == windowType) {
-      theEM.focus();
-      needToOpen = false;
-      break;
-    }
+  var theEM = wm.getMostRecentWindow(EMTYPE);
+  if (theEM) {
+    theEM.focus();
+    return;
   }
 
-  if (needToOpen) {
-    const EMURL = "chrome://mozapps/content/extensions/extensions.xul?type=" + aOpenMode;
-    const EMFEATURES = "chrome,dialog=no,resizable";
-    window.openDialog(EMURL, "", EMFEATURES);
-  }
+  const EMURL = "chrome://mozapps/content/extensions/extensions.xul";
+  const EMFEATURES = "chrome,menubar,extra-chrome,toolbar,dialog=no,resizable";
+  window.openDialog(EMURL, "", EMFEATURES);
 }
 
 function SetBusyCursor(window, enable)
@@ -173,13 +177,70 @@ function SetBusyCursor(window, enable)
 		SetBusyCursor(window.frames[i], enable);
 }
 
-// Macintosh window menu functions
-
-//@line 259 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailCore.js"
-
 function openAboutDialog()
 {
-//@line 265 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailCore.js"
+//@line 221 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailCore.js"
   window.openDialog("chrome://messenger/content/aboutDialog.xul", "About", "modal,centerscreen,chrome,resizable=no");
-//@line 267 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailCore.js"
+//@line 223 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/base/content/mailCore.js"
+}
+
+/**
+ * Opens region specific web pages for the application like the release notes, the help site, etc. 
+ *   aResourceName --> the string resource ID in region.properties to load. 
+ */
+function openRegionURL(aResourceName)
+{
+  var appInfo = Components.classes["@mozilla.org/xre/app-info;1"]
+                          .getService(Components.interfaces.nsIXULAppInfo);
+  try {
+    var strBundleService = Components.classes["@mozilla.org/intl/stringbundle;1"].getService(Components.interfaces.nsIStringBundleService);
+    var regionBundle = strBundleService.createBundle("chrome://messenger-region/locale/region.properties");
+    // the release notes are special and need to be formatted with the app version
+    var urlToOpen;
+    if (aResourceName == "releaseNotesURL")
+      urlToOpen = regionBundle.formatStringFromName(aResourceName, [appInfo.version], 1);
+    else
+      urlToOpen = regionBundle.GetStringFromName(aResourceName);
+      
+    var uri = Components.classes["@mozilla.org/network/io-service;1"]
+              .getService(Components.interfaces.nsIIOService)
+              .newURI(urlToOpen, null, null);
+
+    var protocolSvc = Components.classes["@mozilla.org/uriloader/external-protocol-service;1"]
+                      .getService(Components.interfaces.nsIExternalProtocolService);
+    protocolSvc.loadUrl(uri);
+  } catch (ex) {}
+}
+
+/**
+ *  Fetches the url for the passed in pref name, formats it and then loads it in the default
+ *  browser.
+ *
+ *  @param aPrefName - name of the pref that holds the url we want to format and open
+ */
+function openFormattedRegionURL(aPrefName)
+{
+  var formattedUrl = getFormattedRegionURL(aPrefName);
+  
+  var uri = Components.classes["@mozilla.org/network/io-service;1"].
+                       getService(Components.interfaces.nsIIOService).
+                       newURI(formattedUrl, null, null);
+
+  var protocolSvc = Components.classes["@mozilla.org/uriloader/external-protocol-service;1"].
+                               getService(Components.interfaces.nsIExternalProtocolService);
+  protocolSvc.loadUrl(uri);  
+}
+
+/**
+ *  Fetches the url for the passed in pref name and uses the URL formatter service to 
+ *    process it.
+ *
+ *  @param aPrefName - name of the pref that holds the url we want to format and open
+ *  @returns the formatted url string
+ */
+function getFormattedRegionURL(aPrefName)
+{
+  var formatter = Components.classes["@mozilla.org/toolkit/URLFormatterService;1"].
+                             getService(Components.interfaces.nsIURLFormatter);
+  return formatter.formatURLPref(aPrefName);
 }
