@@ -1,4 +1,4 @@
-//@line 36 "/builds/tinderbox/thunderbird-trunk/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/fonts.js"
+//@line 38 "/builds/tinderbox/Tb-Mozilla1.8/Linux_2.4.18-14_Depend/mozilla/mail/components/preferences/fonts.js"
 
 const kDefaultFontType          = "font.default.%LANG%";
 const kFontNameFmtSerif         = "font.name.serif.%LANG%";
@@ -12,6 +12,13 @@ const kFontSizeFmtFixed         = "font.size.fixed.%LANG%";
 const kFontMinSizeFmt           = "font.minimum-size.%LANG%";
 
 var gFontsDialog = {
+  _init: function()
+  {
+    // build the charset menu list. We do this by hand instead of using the xul template
+    // builder because of Bug #285076, 
+    this.createCharsetMenus(document.getElementById("viewDefaultCharset-menupopup"), "NC:DecodersRoot",
+                            document.getElementById('mailnews.view_default_charset').value);  
+  },
 
   _selectLanguageGroup: function (aLanguageGroup)
   {
@@ -105,82 +112,58 @@ var gFontsDialog = {
     var useDocumentFonts = document.getElementById("useDocumentFonts");
     return useDocumentFonts.checked ? 1 : 0;
   },
-
-  readScreenResolution: function ()
-  {
-    // Initialize the display names of the default values the first time
-    // the preference is read. We can NOT do this in the init function since
-    // that is called after preference loading. 
-    var defaultResolution = document.getElementById("defaultResolution");
-    if (defaultResolution.label == "") {
-      var bundlePreferences = document.getElementById("bundlePreferences");
-      var otherResolution = document.getElementById("otherResolution");
-      otherResolution.label = bundlePreferences.getFormattedString("fontScalingResolutionFormat",
-                                                                  [otherResolution.getAttribute("value")]);
-      defaultResolution.label = bundlePreferences.getFormattedString("fontScalingResolutionFormat",
-                                                                    [defaultResolution.getAttribute("value")]);
-    }
-    return undefined;
+  addMenuItem: function(aMenuPopup, aLabel, aValue)
+  { 
+    var menuItem = document.createElement('menuitem');
+    menuItem.setAttribute('label', aLabel);
+    menuItem.setAttribute('value', aValue);
+    aMenuPopup.appendChild(menuItem);
   },
 
-  changeScreenResolution: function (aMenulist)
+  readRDFString: function(aDS,aRes,aProp) 
   {
-    var userResolution = document.getElementById("userResolution");
-    var screenResolution = document.getElementById("screenResolution");
-    var lastSelected = screenResolution.getElementsByAttribute("lastSelected", "true")
-    if (lastSelected.length > 0) 
-      lastSelected = lastSelected[0];
-    else {
-      var preference = document.getElementById("browser.display.screen_resolution");
-      lastSelected = screenResolution.getElementsByAttribute("value", preference.value);
-      if (lastSelected.length > 0)
-        lastSelected = lastSelected[0];
-      else
-        lastSelected = document.getElementById("defaultResolution");
-    }
-
-    if (aMenulist.selectedItem.value == "choose") {
-      var rv = { newdpi: -1 };
-      document.documentElement.openSubDialog("chrome://mozapps/content/preferences/fontscaling.xul",
-                                             "", rv);
-      if (rv.newdpi != -1) {
-        this._setResolution(rv.newdpi);
-        lastSelected.removeAttribute("lastSelected");
-        screenResolution.selectedItem.setAttribute("lastSelected", "true");
-      }
-      else
-        screenResolution.selectedItem = lastSelected;
-    }
-    else if (!(screenResolution.value == userResolution.value)) {
-      // User has selected one of the hard-coded resolutions
-      userResolution.hidden = true;
-      lastSelected.removeAttribute("lastSelected");
-      screenResolution.selectedItem.setAttribute("lastSelected", "true");
-    }
+    var n = aDS.GetTarget(aRes, aProp, true);
+    return (n) ? n.QueryInterface(Components.interfaces.nsIRDFLiteral).Value : "";
   },
 
-  _setResolution: function (aResolution)
+  createCharsetMenus: function(aMenuPopup, aRoot, aPreferenceValue)
   {
-    // Given a number, if it's equal to a hard-coded resolution we use that,
-    // otherwise we set the userResolution field.
-    var screenResolution = document.getElementById("screenResolution");
-    var userResolution = document.getElementById("userResolution");
+    var rdfService = Components.classes["@mozilla.org/rdf/rdf-service;1"]
+                     .getService(Components.interfaces.nsIRDFService);
+    var kNC_Root = rdfService.GetResource(aRoot);
+    var kNC_Name = rdfService.GetResource("http://home.netscape.com/NC-rdf#Name");
 
-    var items = screenResolution.getElementsByAttribute("value", aResolution);
-    if (items[0]) {
-      // If it's one of the hard-coded values, we'll select it directly 
-      screenResolution.selectedItem = items[0];
-      userResolution.hidden = true;
-    }   
-    else {
-      // Otherwise we need to set up the userResolution field
-      var bundlePreferences = document.getElementById("bundlePreferences");
-      var label = bundlePreferences.getFormattedString("fontScalingResolutionFormat", 
-                                                       [aResolution]);
-      userResolution.value = aResolution;
-      userResolution.label = label;
-      userResolution.hidden = false;
-      screenResolution.selectedItem = userResolution;
-    }
+    var rdfDataSource = rdfService.GetDataSource("rdf:charset-menu");
+    var rdfContainer = Components.classes["@mozilla.org/rdf/container;1"].getService(Components.interfaces.nsIRDFContainer);
+    rdfContainer.Init(rdfDataSource, kNC_Root);
+
+    var charset;
+    var availableCharsets = rdfContainer.GetElements();
+
+    for (var i = 0; i < rdfContainer.GetCount(); i++) 
+    {
+      charset = availableCharsets.getNext().QueryInterface(Components.interfaces.nsIRDFResource);
+
+      this.addMenuItem(aMenuPopup, this.readRDFString(rdfDataSource, charset, kNC_Name), charset.Value);
+      if (charset.Value == aPreferenceValue)
+        aMenuPopup.parentNode.value = charset.Value;
+    }         
+  },
+  
+  mCharsetMenuInitialized: false,
+  readDefaultCharset: function()
+  {
+    if (!this.mCharsetMenuInitialized) 
+    {
+      Components.classes["@mozilla.org/observer-service;1"]
+                .getService(Components.interfaces.nsIObserverService)
+                .notifyObservers(null, "charsetmenu-selected", "mailedit");
+      // build the charset menu list. We do this by hand instead of using the xul template
+      // builder because of Bug #285076, 
+      this.createCharsetMenus(document.getElementById("sendDefaultCharset-menupopup"), "NC:MaileditCharsetMenuRoot",
+                              document.getElementById('mailnews.send_default_charset').value);
+      this.mCharsetMenuInitialized = true;
   }
+    return undefined;
+  },  
 };
